@@ -40,10 +40,14 @@ class TelegramUploadDataLoss(TelegramUploadError):
     error_code = 29
 
 
+class TelegramProxyError(TelegramUploadError):
+    error_code = 30
+
+
 def catch(fn):
     def wrap(*args, **kwargs):
         try:
-            fn(*args, **kwargs)
+            return fn(*args, **kwargs)
         except TelegramUploadError as e:
             sys.stderr.write('[Error] telegram-upload Exception:\n{}\n'.format(e))
             exit(e.error_code)
